#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 os-string
version:              2.0.11
visibility:           public
id:                   os-string-2.0.11-IpDNpZR2uou2cPDz7qoMUq
key:                  os-string-2.0.11-IpDNpZR2uou2cPDz7qoMUq
license:              BSD-3-Clause
copyright:            Julian Ospald 2021-2023
maintainer:           Julian Ospald <hasufell@posteo.de>
author:               Julian Ospald <hasufell@posteo.de>
homepage:             https://github.com/haskell/os-string/blob/master/README.md
synopsis:             Library for manipulating Operating system strings.
description:
    This package provides functionality for manipulating @OsString@ values, and is shipped with <https://www.haskell.org/ghc/ GHC>.

category:             System
abi:                  eca2fb1231fa58a2ca0ab00c20e4b861
exposed:              True
exposed-modules:
    System.OsString System.OsString.Data.ByteString.Short
    System.OsString.Data.ByteString.Short.Internal
    System.OsString.Data.ByteString.Short.Word16
    System.OsString.Encoding System.OsString.Encoding.Internal
    System.OsString.Internal System.OsString.Internal.Exception
    System.OsString.Internal.Types System.OsString.Posix
    System.OsString.Windows

import-dirs:          /usr/lib/ghc-9.6.6/site-local/os-string-2.0.11
library-dirs:         /usr/lib/ghc-9.6.6/site-local/os-string-2.0.11
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/os-string-2.0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-os-string
hs-libraries:         HSos-string-2.0.11-IpDNpZR2uou2cPDz7qoMUq
depends:
    base-4.18.2.1 bytestring-0.11.5.3 deepseq-1.4.8.1 exceptions-0.10.7
    template-haskell-2.20.0.0

haddock-interfaces:   /usr/share/doc/haskell-os-string/html/os-string.haddock
haddock-html:         /usr/share/doc/haskell-os-string/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

